NativeTexture class

Used to allocate a buffer for displaying a preview camera texture.

This is used to for a developer to have a control over the TextureRegistry.SurfaceTextureEntry (Android) and FlutterTexture (iOS). This gives direct access to the textureId and can be reused with separate camera instances.

The textureId can be passed to a Texture widget.

Mixed-in types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textureId → int
Id that can be passed to a Texture widget.
final

Methods

asMap() → Map<String, dynamic>
Creates a description of the object compatible with PlatformChannels.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → Future<void>
Deallocate this texture.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

allocate() → Future<NativeTexture>